@@ -23,32 +23,24 @@
 #include <config.h>
 #endif
 
-#include "gtksourcebuffer.h"
 #include "gtksourceengine.h"
 #include "gtksourcestylescheme.h"
 
-G_DEFINE_TYPE (GtkSourceEngine, _gtk_source_engine, G_TYPE_OBJECT)
+G_DEFINE_INTERFACE (GtkSourceEngine, _gtk_source_engine, G_TYPE_OBJECT)
 
 static void
-_gtk_source_engine_class_init (GtkSourceEngineClass *klass)
-{
-	klass->attach_buffer = NULL;
-}
-
-
-static void
-_gtk_source_engine_init (G_GNUC_UNUSED GtkSourceEngine *engine)
+_gtk_source_engine_default_init (GtkSourceEngineInterface *interface)
 {
 }
 
 void
 _gtk_source_engine_attach_buffer (GtkSourceEngine *engine,
-				 GtkTextBuffer   *buffer)
+				  GtkTextBuffer   *buffer)
 {
 	g_return_if_fail (GTK_SOURCE_IS_ENGINE (engine));
-	g_return_if_fail (GTK_SOURCE_ENGINE_GET_CLASS (engine)->attach_buffer != NULL);
+	g_return_if_fail (GTK_SOURCE_ENGINE_GET_INTERFACE (engine)->attach_buffer != NULL);
 
-	GTK_SOURCE_ENGINE_GET_CLASS (engine)->attach_buffer (engine, buffer);
+	GTK_SOURCE_ENGINE_GET_INTERFACE (engine)->attach_buffer (engine, buffer);
 }
 
 void
@@ -57,11 +49,11 @@ _gtk_source_engine_text_inserted (GtkSourceEngine *engine,
 				  gint             end_offset)
 {
 	g_return_if_fail (GTK_SOURCE_IS_ENGINE (engine));
-	g_return_if_fail (GTK_SOURCE_ENGINE_GET_CLASS (engine)->text_inserted != NULL);
+	g_return_if_fail (GTK_SOURCE_ENGINE_GET_INTERFACE (engine)->text_inserted != NULL);
 
-	GTK_SOURCE_ENGINE_GET_CLASS (engine)->text_inserted (engine,
-							     start_offset,
-							     end_offset);
+	GTK_SOURCE_ENGINE_GET_INTERFACE (engine)->text_inserted (engine,
+								 start_offset,
+								 end_offset);
 }
 
 void
@@ -70,11 +62,11 @@ _gtk_source_engine_text_deleted (GtkSourceEngine *engine,
 				 gint             length)
 {
 	g_return_if_fail (GTK_SOURCE_IS_ENGINE (engine));
-	g_return_if_fail (GTK_SOURCE_ENGINE_GET_CLASS (engine)->text_deleted != NULL);
+	g_return_if_fail (GTK_SOURCE_ENGINE_GET_INTERFACE (engine)->text_deleted != NULL);
 
-	GTK_SOURCE_ENGINE_GET_CLASS (engine)->text_deleted (engine,
-							    offset,
-							    length);
+	GTK_SOURCE_ENGINE_GET_INTERFACE (engine)->text_deleted (engine,
+								offset,
+								length);
 }
 
 void
@@ -85,12 +77,12 @@ _gtk_source_engine_update_highlight (GtkSourceEngine   *engine,
 {
 	g_return_if_fail (GTK_SOURCE_IS_ENGINE (engine));
 	g_return_if_fail (start != NULL && end != NULL);
-	g_return_if_fail (GTK_SOURCE_ENGINE_GET_CLASS (engine)->update_highlight != NULL);
+	g_return_if_fail (GTK_SOURCE_ENGINE_GET_INTERFACE (engine)->update_highlight != NULL);
 
-	GTK_SOURCE_ENGINE_GET_CLASS (engine)->update_highlight (engine,
-								start,
-								end,
-								synchronous);
+	GTK_SOURCE_ENGINE_GET_INTERFACE (engine)->update_highlight (engine,
+								    start,
+								    end,
+								    synchronous);
 }
 
 void
@@ -99,9 +91,9 @@ _gtk_source_engine_set_style_scheme (GtkSourceEngine      *engine,
 {
 	g_return_if_fail (GTK_SOURCE_IS_ENGINE (engine));
 	g_return_if_fail (GTK_SOURCE_IS_STYLE_SCHEME (scheme) || scheme == NULL);
-	g_return_if_fail (GTK_SOURCE_ENGINE_GET_CLASS (engine)->set_style_scheme != NULL);
+	g_return_if_fail (GTK_SOURCE_ENGINE_GET_INTERFACE (engine)->set_style_scheme != NULL);
 
-	GTK_SOURCE_ENGINE_GET_CLASS (engine)->set_style_scheme (engine, scheme);
+	GTK_SOURCE_ENGINE_GET_INTERFACE (engine)->set_style_scheme (engine, scheme);
 }
 
 GtkTextTag *
@@ -111,6 +103,6 @@ _gtk_source_engine_get_context_class_tag (GtkSourceEngine *engine,
 	g_return_val_if_fail (GTK_SOURCE_IS_ENGINE (engine), NULL);
 	g_return_val_if_fail (context_class != NULL, NULL);
 
-	return GTK_SOURCE_ENGINE_GET_CLASS (engine)->get_context_class_tag (engine,
-									    context_class);
+	return GTK_SOURCE_ENGINE_GET_INTERFACE (engine)->get_context_class_tag (engine,
+										context_class);
 }
